==> jc-1.4.0.tar.gz: javax/imageio/spi/IIORegistry.h <==
// public final class javax.imageio.spi.IIORegistry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dfa20be1228839ac javax_imageio_spi_IIORegistry
// @dep_class ebaf215a1291ec07 javax_imageio_spi_ServiceRegistry

// header file dependencies
// @dep_header javax_imageio_spi_ServiceRegistry

#include "javax/imageio/spi/ServiceRegistry.h"

#ifndef _JC_javax_imageio_spi_IIORegistry_H_
#define _JC_javax_imageio_spi_IIORegistry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashSet$object;
struct _jc_javax_imageio_spi_IIORegistry$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_IIORegistry$sub_refs	_jc_javax_imageio_spi_IIORegistry$sub_refs;
typedef struct _jc_javax_imageio_spi_IIORegistry$sub_nonrefs	_jc_javax_imageio_spi_IIORegistry$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_IIORegistry$refs	_jc_javax_imageio_spi_IIORegistry$refs;
typedef struct _jc_javax_imageio_spi_IIORegistry$nonrefs	_jc_javax_imageio_spi_IIORegistry$nonrefs;
typedef struct _jc_javax_imageio_spi_IIORegistry$object	_jc_javax_imageio_spi_IIORegistry$object;

typedef struct _jc_javax_imageio_spi_IIORegistry$fields_struct	_jc_javax_imageio_spi_IIORegistry$fields_struct;
typedef const struct _jc_javax_imageio_spi_IIORegistry$vmethods	_jc_javax_imageio_spi_IIORegistry$vmethods;
typedef const struct _jc_javax_imageio_spi_IIORegistry$vtable	_jc_javax_imageio_spi_IIORegistry$vtable;
typedef const struct _jc_javax_imageio_spi_IIORegistry$vtype	_jc_javax_imageio_spi_IIORegistry$vtype;

// Class fields structure
struct _jc_javax_imageio_spi_IIORegistry$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageInputStreamSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageOutputStreamSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageReaderSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageTranscoderSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageWriterSpi;
	struct _jc_java_util_HashSet$object	*defaultCategories;
	struct _jc_java_util_HashMap$object	*instances;
};
extern _jc_javax_imageio_spi_IIORegistry$fields_struct _jc_javax_imageio_spi_IIORegistry$class_fields;

// Constructors
extern void _jc_javax_imageio_spi_IIORegistry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_IIORegistry$object *);

// Virtual methods
extern void _jc_javax_imageio_spi_IIORegistry$method$registerApplicationClasspathSpis$54a78edb6353ba2d(_jc_env *, struct _jc_javax_imageio_spi_IIORegistry$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_IIORegistry$method_info$registerApplicationClasspathSpis$54a78edb6353ba2d;

// Static methods
extern void _jc_javax_imageio_spi_IIORegistry$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_imageio_spi_IIORegistry$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_javax_imageio_spi_IIORegistry$object *_jc_javax_imageio_spi_IIORegistry$method$getDefaultInstance$687f723d5a58e932(_jc_env *);

// Virtual methods structure
struct _jc_javax_imageio_spi_IIORegistry$vmethods {
	void	(*registerApplicationClasspathSpis$54a78edb6353ba2d)(_jc_env *, struct _jc_javax_imageio_spi_IIORegistry$object *);
};

// Vtable
struct _jc_javax_imageio_spi_IIORegistry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_ServiceRegistry$vmethods	javax_imageio_spi_ServiceRegistry;
	_jc_javax_imageio_spi_IIORegistry$vmethods	javax_imageio_spi_IIORegistry;
};

// Vtype
struct _jc_javax_imageio_spi_IIORegistry$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_IIORegistry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIORegistry$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_IIORegistry$refs {
    _jc_javax_imageio_spi_IIORegistry$sub_refs	javax_imageio_spi_IIORegistry;
    _jc_javax_imageio_spi_ServiceRegistry$sub_refs	javax_imageio_spi_ServiceRegistry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIORegistry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_IIORegistry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_ServiceRegistry$sub_nonrefs	javax_imageio_spi_ServiceRegistry;
    _jc_javax_imageio_spi_IIORegistry$sub_nonrefs	javax_imageio_spi_IIORegistry;
};

// Object instance structure
struct _jc_javax_imageio_spi_IIORegistry$object {
	_jc_javax_imageio_spi_IIORegistry$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_IIORegistry$vtype	*vtype;
	_jc_javax_imageio_spi_IIORegistry$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_IIORegistry$vtype _jc_javax_imageio_spi_IIORegistry$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_IIORegistry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_IIORegistry$class_object;

#endif	/* _JC_javax_imageio_spi_IIORegistry_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/spi/IIORegistry.h <==
// public final class javax.imageio.spi.IIORegistry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class da8c56b068d238c4 javax_imageio_spi_IIORegistry
// @dep_class ebaf215a1291ec07 javax_imageio_spi_ServiceRegistry

// header file dependencies
// @dep_header javax_imageio_spi_ServiceRegistry

#include "javax/imageio/spi/ServiceRegistry.h"

#ifndef _JC_javax_imageio_spi_IIORegistry_H_
#define _JC_javax_imageio_spi_IIORegistry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashSet$object;
struct _jc_javax_imageio_spi_IIORegistry$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_IIORegistry$sub_refs	_jc_javax_imageio_spi_IIORegistry$sub_refs;
typedef struct _jc_javax_imageio_spi_IIORegistry$sub_nonrefs	_jc_javax_imageio_spi_IIORegistry$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_IIORegistry$refs	_jc_javax_imageio_spi_IIORegistry$refs;
typedef struct _jc_javax_imageio_spi_IIORegistry$nonrefs	_jc_javax_imageio_spi_IIORegistry$nonrefs;
typedef struct _jc_javax_imageio_spi_IIORegistry$object	_jc_javax_imageio_spi_IIORegistry$object;

typedef struct _jc_javax_imageio_spi_IIORegistry$fields_struct	_jc_javax_imageio_spi_IIORegistry$fields_struct;
typedef const struct _jc_javax_imageio_spi_IIORegistry$vmethods	_jc_javax_imageio_spi_IIORegistry$vmethods;
typedef const struct _jc_javax_imageio_spi_IIORegistry$vtable	_jc_javax_imageio_spi_IIORegistry$vtable;
typedef const struct _jc_javax_imageio_spi_IIORegistry$vtype	_jc_javax_imageio_spi_IIORegistry$vtype;

// Class fields structure
struct _jc_javax_imageio_spi_IIORegistry$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageInputStreamSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageOutputStreamSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageReaderSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageTranscoderSpi;
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24spi__24ImageWriterSpi;
	struct _jc_java_util_HashSet$object	*defaultCategories;
	struct _jc_java_util_HashMap$object	*instances;
};
extern _jc_javax_imageio_spi_IIORegistry$fields_struct _jc_javax_imageio_spi_IIORegistry$class_fields;

// Constructors
extern void _jc_javax_imageio_spi_IIORegistry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_IIORegistry$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_imageio_spi_IIORegistry$method$registerApplicationClasspathSpis$54a78edb6353ba2d(_jc_env *, struct _jc_javax_imageio_spi_IIORegistry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_IIORegistry$method_info$registerApplicationClasspathSpis$54a78edb6353ba2d;

// Static methods
extern void _jc_javax_imageio_spi_IIORegistry$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_imageio_spi_IIORegistry$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_javax_imageio_spi_IIORegistry$object *_jc_javax_imageio_spi_IIORegistry$method$getDefaultInstance$687f723d5a58e932(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_imageio_spi_IIORegistry$vmethods {
	void	(*registerApplicationClasspathSpis$54a78edb6353ba2d)(_jc_env *, struct _jc_javax_imageio_spi_IIORegistry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_spi_IIORegistry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_ServiceRegistry$vmethods	javax_imageio_spi_ServiceRegistry;
	_jc_javax_imageio_spi_IIORegistry$vmethods	javax_imageio_spi_IIORegistry;
};

// Vtype
struct _jc_javax_imageio_spi_IIORegistry$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_IIORegistry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIORegistry$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_IIORegistry$refs {
    _jc_javax_imageio_spi_IIORegistry$sub_refs	javax_imageio_spi_IIORegistry;
    _jc_javax_imageio_spi_ServiceRegistry$sub_refs	javax_imageio_spi_ServiceRegistry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIORegistry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_IIORegistry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_ServiceRegistry$sub_nonrefs	javax_imageio_spi_ServiceRegistry;
    _jc_javax_imageio_spi_IIORegistry$sub_nonrefs	javax_imageio_spi_IIORegistry;
};

// Object instance structure
struct _jc_javax_imageio_spi_IIORegistry$object {
	_jc_javax_imageio_spi_IIORegistry$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_IIORegistry$vtype	*vtype;
	_jc_javax_imageio_spi_IIORegistry$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_IIORegistry$vtype _jc_javax_imageio_spi_IIORegistry$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_IIORegistry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_IIORegistry$class_object;

#endif	/* _JC_javax_imageio_spi_IIORegistry_H_ */
